@@ -78,14 +78,17 @@ def saveFile(content, fullpath):
 def saveData(obj, fullpath):
     if obj is None:
         return
-    if type(obj) == list or type(obj) == dict:
-        if len(obj) == 0:
-            return
+    # if type(obj) == list or type(obj) == dict:
+    #     if len(obj) == 0:
+    #         return
     saveFile(jobj(obj), fullpath)
 
 
 def loadData(fullpath):
-    with open(fullpath, 'r') as file:
+    if not filepath:
+        return None
+    if not os.path.exists(filepath):
+        return None    with open(fullpath, 'r') as file:
         content = file.read()
     try:
         return json.loads(content)
@@ -156,36 +159,58 @@ class FileTree(object):
         self.__getFileAndFolder()
 
     def __getFileAndFolder(self):
-        folder = self.__root_path.split('/')[-1]
-        for file_dir, path, files in os.walk(folder):
+        for file_dir, path, files in os.walk(self.__root_path):
             path = excludeFiles(path)
             files = excludeFiles(files)
             for p in path:
                 t = FileTree(os.path.join(file_dir, p))
                 self.__paths.append(t)
             if len(files) > 0:
-                self.__files.extend(files)
+                arr_files = []
+                for file in files:
+                    full_name = os.path.join(file_dir, file)
+                    tmp = {
+                        'name': file,
+                        'full_name': full_name,
+                        'size': os.path.getsize(full_name),  # bytes
+                    }
+                    arr_files.append(tmp)
+                self.__files.extend(arr_files)
             break
 
     def __sortFiles(self, files):
         a = []
         b = []
         for f in files[:]:
-            if re.findall(r'^\d+', f):
+            if re.findall(r'^\d+', f) != []:
                 a.append(f)
             else:
                 b.append(f)
-        a = sorted(a, key=lambda f: int(re.findall(r'^\d+', f)[0]))
-        b = sorted(b)
-        return a + b
+        a = sorted(a, key = lambda f: int(re.findall(r'^\d+', f)[0]))
+        b = sorted(b, key = lambda f: f)
+        return a+b
 
     def files(self):
-        return self.__sortFiles(self.__files[:])
+        files = [it['name'] for it in self.__files]
+        return self.__sortFiles(files)
+
+    def files_full(self):
+        files = [it['full_name'] for it in self.__files]
+        return self.__sortFiles(files)
 
     def paths(self):
         arr = [t.root() for t in self.__paths]
+        # jprint(arr)
         return self.__sortFiles(arr)
 
+    def get_size(self):
+        size = 0
+        for p in self.__paths:
+            size += p.get_size()
+        for f in self.__files:
+            size += f.get('size', 0)
+        return size
+
     def cd(self, path):
         for tree in self.__paths:
             if path == tree.root():
@@ -197,13 +222,13 @@ class FileTree(object):
 
     def obj(self):
         arr = []
-        arr.extend(self.__files)
+        arr.extend(self.files())
         for p in self.__paths:
             arr.append({p.root(): p.obj()})
         return arr
 
     def __str__(self):
-        return '%s:\n%s' % (self.root(), jobj(self.obj()))
+        return '%s:\n%s' % (self.root(), dumps(self.obj()))
 
 
 def get_files(dir):
